summaryrefslogtreecommitdiffstats
path: root/kpovmodeler/pmpolynomedit.h
diff options
context:
space:
mode:
Diffstat (limited to 'kpovmodeler/pmpolynomedit.h')
-rw-r--r--kpovmodeler/pmpolynomedit.h5
1 files changed, 3 insertions, 2 deletions
diff --git a/kpovmodeler/pmpolynomedit.h b/kpovmodeler/pmpolynomedit.h
index 1d745437..2a1e5898 100644
--- a/kpovmodeler/pmpolynomedit.h
+++ b/kpovmodeler/pmpolynomedit.h
@@ -39,12 +39,13 @@ class TQCheckBox;
class PMPolynomEdit : public PMSolidObjectEdit
{
Q_OBJECT
+ TQ_OBJECT
typedef PMSolidObjectEdit Base;
public:
/**
* Creates a PMPolynomEdit with parent and name
*/
- PMPolynomEdit( TQWidget* parent, const char* name = 0 );
+ PMPolynomEdit( TQWidget* tqparent, const char* name = 0 );
/** */
virtual void displayObject( PMObject* o );
@@ -39,12 +39,13 @@ class TQCheckBox;
public:
/**
- * Creates a PMPolynomEdit with parent and name
+ * Creates a PMPolynomEdit with tqparent and name
*/